==> breeze_update_3.6.05.tar.gz: manage/save_options.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 11/13/2008	ELL
// Added data type handling for text boxes as well as drop downs.
// Revised: 6/17/2009	ELL
// Added capability to handle checkbox data type, i.e. if checked, set value to 1, otherwise 0.
// Revised: 2/10/2012	ELL
// Added table prefix handling.
// 
	include ("check_session.php");
	
	$option_name = array();
	$option_value = array();
	$data_type = array();
	
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options` ORDER BY `option_name`";
	$result = mysql_query($query, $bwb_link);
	$num_results = mysql_num_rows($result);
	$k = 0;
	$last_option_name = "-none-";
	for ($i = 0; $i < $num_results; $i++)
	{
		$row = mysql_fetch_array($result);
		if ($last_option_name != $row["option_name"])
		{
			$option_name[$k] = $row["option_name"];
			$data_type[$k] = $row["data_type"];
			$option_value[$k] = $_POST[$option_name[$k]];
			if ($data_type[$k] == 2) //checkbox type
			{
				if (isset($option_value[$k]))
					$option_value[$k] = 1;
				else
					$option_value[$k] = 0;
			}
			$last_option_name = $option_name[$k];
			$k++;
		}
	}
	
	//Insert new data into table.
	for ($i = 0; $i < $k; $i++)
	{
		$query2 = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name` = '$option_name[$i]'";
		$result2 = mysql_query($query2, $bwb_link);
		if (mysql_num_rows($result2) > 0)
			$query = "UPDATE `" . BWB_TABLE_PREFIX . "options_selected` SET `option_value` = '$option_value[$i]' WHERE `option_name` = '$option_name[$i]'";
		else
			$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "options_selected` (`option_name`, `option_value`) VALUES ('$option_name[$i]', '$option_value[$i]')";
		$result = mysql_query($query, $bwb_link);
	}
	
	header("Location: main.php?mode=admin");
	
?>

==> breeze_update_4.0.01.tar.gz: manage/save_options.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 11/13/2008	ELL
// Added data type handling for text boxes as well as drop downs.
// Revised: 6/17/2009	ELL
// Added capability to handle checkbox data type, i.e. if checked, set value to 1, otherwise 0.
// Revised: 2/10/2012	ELL
// Added table prefix handling.
// 
	include ("check_session.php");
	
	$option_name = array();
	$option_value = array();
	$data_type = array();
	
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options` ORDER BY `option_name`";
	$result = $bwb_dbh->query($query);
	$num_results = $result->rowCount();
	$k = 0;
	$last_option_name = "-none-";
	for ($i = 0; $i < $num_results; $i++)
	{
		$row = $result->fetch(PDO::FETCH_ASSOC);
		if ($last_option_name != $row["option_name"])
		{
			$option_name[$k] = $row["option_name"];
			$data_type[$k] = $row["data_type"];
			$option_value[$k] = $_POST[$option_name[$k]];
			if ($data_type[$k] == 2) //checkbox type
			{
				if (isset($option_value[$k]))
					$option_value[$k] = 1;
				else
					$option_value[$k] = 0;
			}
			$last_option_name = $option_name[$k];
			$k++;
		}
	}
	
	//Insert new data into table.
	for ($i = 0; $i < $k; $i++)
	{
		$query2 = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name` = '$option_name[$i]'";
		$result2 = $bwb_dbh->query($query2);
		if ($result2->rowCount() > 0)
			$query = "UPDATE `" . BWB_TABLE_PREFIX . "options_selected` SET `option_value` = '$option_value[$i]' WHERE `option_name` = '$option_name[$i]'";
		else
			$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "options_selected` (`option_name`, `option_value`) VALUES ('$option_name[$i]', '$option_value[$i]')";
		$cnt = $bwb_dbh->exec($query);
	}
	
	header("Location: main.php?mode=admin");
	
?>
